==> genometools-1.0.3.tar.gz: genometools-1.0.3/src/libgtext/genome_node_rep.h <==
/*
  Copyright (c) 2006-2007 Gordon Gremme <gremme@zbh.uni-hamburg.de>
  Copyright (c) 2006-2007 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef GENOME_NODE_REP_H
#define GENOME_NODE_REP_H

#include <stdio.h>
#include "libgtcore/dlist.h"
#include "libgtext/genome_node.h"
#include "libgtext/genome_node_info.h"

/* the ``genome node'' interface */
struct GenomeNodeClass
{
  size_t size;
  void  (*free)(GenomeNode*, Env*);
  Str*  (*get_seqid)(GenomeNode*);
  Str*  (*get_idstr)(GenomeNode*);
  Range (*get_range)(GenomeNode*);
  void  (*set_range)(GenomeNode*, Range);
  void  (*set_seqid)(GenomeNode*, Str*);
  void  (*set_source)(GenomeNode*, Str*);
  void  (*set_phase)(GenomeNode*, Phase);
  int   (*accept)(GenomeNode*, GenomeVisitor*, Env*);
};

struct GenomeNode
{
  const GenomeNodeClass *c_class;
  Str *filename;
  unsigned long line_number;
  Dlist *children;
  unsigned int reference_count;
  GenomeNodeInfo info;
  bool mark;
};

GenomeNode* genome_node_create(const GenomeNodeClass*, Str *filename,
                               unsigned long line_number, Env *env);

#endif

==> genometools-1.0.5.tar.gz: genometools-1.0.5/src/libgtext/genome_node_rep.h <==
/*
  Copyright (c) 2006-2007 Gordon Gremme <gremme@zbh.uni-hamburg.de>
  Copyright (c) 2006-2007 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef GENOME_NODE_REP_H
#define GENOME_NODE_REP_H

#include <stdio.h>
#include "libgtcore/dlist.h"
#include "libgtext/genome_node.h"
#include "libgtext/genome_node_info.h"

/* the ``genome node'' interface */
struct GenomeNodeClass
{
  size_t size;
  void  (*free)(GenomeNode*, Env*);
  Str*  (*get_seqid)(GenomeNode*);
  Str*  (*get_idstr)(GenomeNode*);
  Range (*get_range)(GenomeNode*);
  void  (*set_range)(GenomeNode*, Range);
  void  (*set_seqid)(GenomeNode*, Str*, Env*);
  void  (*set_source)(GenomeNode*, Str*);
  void  (*set_phase)(GenomeNode*, Phase);
  int   (*accept)(GenomeNode*, GenomeVisitor*, Env*);
};

struct GenomeNode
{
  const GenomeNodeClass *c_class;
  Str *filename;
  unsigned long line_number;
  Dlist *children;
  unsigned int reference_count;
  GenomeNodeInfo info;
  bool mark;
};

GenomeNode* genome_node_create(const GenomeNodeClass*, Str *filename,
                               unsigned long line_number, Env *env);

#endif
